@@ -21,14 +21,14 @@ from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
 
 # CNN2SNN imports
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, quantize
 
-from ..quantization_blocks import conv_block, separable_conv_block
+from ..layer_blocks import conv_block, separable_conv_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/ds_cnn/'
 
 
-def ds_cnn_cifar10(input_shape,
+def ds_cnn_cifar10(input_shape=(32, 32, 3),
                    classes=10,
                    weights=None,
                    weight_quantization=0,
@@ -45,8 +45,8 @@ def ds_cnn_cifar10(input_shape,
     Args:
         input_shape (tuple): input shape tuple of the model
         classes (int): number of classes to classify images into
-        weights (str): one of `None` (random initialization), 'cifar10' for
-            pretrained weights or the path to the weights file to be loaded.
+        weights (str): one of `None` (random initialization) or the path to the
+            weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -81,9 +81,8 @@ def ds_cnn_cifar10(input_shape,
                    kernel_size=(3, 3),
                    padding='same',
                    use_bias=False,
-                   weight_quantization=input_weight_quantization,
-                   activ_quantization=activ_quantization,
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = separable_conv_block(x,
                              filters=128,
@@ -91,9 +90,8 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_1',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=256,
@@ -101,9 +99,8 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_2',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=256,
@@ -111,10 +108,9 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_3',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
                              pooling='max',
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=512,
@@ -122,9 +118,8 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_4',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=512,
@@ -132,10 +127,9 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_5',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
                              pooling='max',
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=512,
@@ -143,9 +137,8 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_6',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=512,
@@ -153,10 +146,9 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_7',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
                              pooling='max',
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=1024,
@@ -164,9 +156,8 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_8',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=1024,
@@ -174,9 +165,8 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_9',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=activ_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=classes,
@@ -184,10 +174,9 @@ def ds_cnn_cifar10(input_shape,
                              name='separable_10',
                              padding='same',
                              use_bias=False,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=None,
                              pooling='global_avg',
-                             add_batchnorm=False)
+                             add_batchnorm=False,
+                             add_activation=False)
 
     model = Model(img_input, x, name='ds_cnn_cifar10')
 
@@ -195,7 +184,12 @@ def ds_cnn_cifar10(input_shape,
     if weights is not None:
         model.load_weights(weights, by_name=True)
 
-    return model
+    if ((weight_quantization != 0) or (activ_quantization != 0) or
+        (input_weight_quantization != 0)):
+        return quantize(model, weight_quantization, activ_quantization,
+                        input_weight_quantization)
+    else:
+        return model
 
 
 def ds_cnn_cifar10_pretrained():
@@ -203,4 +197,4 @@ def ds_cnn_cifar10_pretrained():
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
-    return load_quantized_model(model_path)
\ No newline at end of file
+    return load_quantized_model(model_path)
