@@ -22,14 +22,14 @@ from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
 
 # CNN2SNN imports
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, quantize
 
-from ..quantization_blocks import conv_block, dense_block
+from ..layer_blocks import conv_block, dense_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
 
 
-def vgg_cifar10(input_shape,
+def vgg_cifar10(input_shape=(32, 32, 3),
                 classes=10,
                 weights=None,
                 weight_quantization=0,
@@ -44,8 +44,8 @@ def vgg_cifar10(input_shape,
     Args:
         input_shape (tuple): input shape tuple of the model
         classes (int): number of classes to classify images into
-        weights (str): one of `None` (random initialization), 'cifar10' for
-            pretrained weights or the path to the weights file to be loaded.
+        weights (str): one of `None` (random initialization) or the path to the
+            weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -79,10 +79,8 @@ def vgg_cifar10(input_shape,
                    name='conv_0',
                    padding='same',
                    use_bias=False,
-                   weight_quantization=input_weight_quantization,
-                   activ_quantization=activ_quantization,
-                   pooling=None,
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=128,
@@ -90,10 +88,9 @@ def vgg_cifar10(input_shape,
                    name='conv_1',
                    padding='same',
                    use_bias=False,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
                    pooling='max',
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=256,
@@ -101,10 +98,8 @@ def vgg_cifar10(input_shape,
                    name='conv_2',
                    padding='same',
                    use_bias=False,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
-                   pooling=None,
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=256,
@@ -112,10 +107,9 @@ def vgg_cifar10(input_shape,
                    name='conv_3',
                    padding='same',
                    use_bias=False,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
                    pooling='max',
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=512,
@@ -123,10 +117,8 @@ def vgg_cifar10(input_shape,
                    kernel_size=(3, 3),
                    padding='same',
                    use_bias=False,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
-                   pooling=None,
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=512,
@@ -134,10 +126,9 @@ def vgg_cifar10(input_shape,
                    name='conv_5',
                    padding='same',
                    use_bias=False,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
                    pooling='max',
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=1024,
@@ -145,10 +136,8 @@ def vgg_cifar10(input_shape,
                    name='conv_6',
                    padding='same',
                    use_bias=False,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
-                   pooling=None,
-                   add_batchnorm=True)
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = Flatten()(x)
 
@@ -156,17 +145,15 @@ def vgg_cifar10(input_shape,
                     units=1024,
                     name='dense_7',
                     use_bias=False,
-                    weight_quantization=weight_quantization,
-                    activ_quantization=activ_quantization,
-                    add_batchnorm=True)
+                    add_batchnorm=True,
+                    add_activation=True)
 
     x = dense_block(x,
                     units=classes,
                     name='dense_8',
                     use_bias=False,
-                    weight_quantization=weight_quantization,
-                    activ_quantization=None,
-                    add_batchnorm=False)
+                    add_batchnorm=False,
+                    add_activation=False)
 
     model = Model(img_input, x, name='vgg_cifar10')
 
@@ -174,7 +161,12 @@ def vgg_cifar10(input_shape,
     if weights is not None:
         model.load_weights(weights, by_name=True)
 
-    return model
+    if ((weight_quantization != 0) or (activ_quantization != 0) or
+        (input_weight_quantization != 0)):
+        return quantize(model, weight_quantization, activ_quantization,
+                        input_weight_quantization)
+    else:
+        return model
 
 
 def vgg_cifar10_pretrained():
@@ -182,4 +174,4 @@ def vgg_cifar10_pretrained():
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
-    return load_quantized_model(model_path)
\ No newline at end of file
+    return load_quantized_model(model_path)
