@@ -45,8 +45,8 @@ def tse_mlp_cse2018(numerical_columns=None,
         categorical_columns (dict): dictionary of categorical column names
             indexing the list of vocabulary for the column. Will use
             preprocessed data when set to `None`.
-        weights (str): one of `None` (random initialization), 'cse2018' for
-            pretrained weights or the path to the weights file to be loaded.
+        weights (str): one of `None` (random initialization) or the path to the
+            weights file to be loaded.
         weight_quantization (int): sets MLP weights in the model to have a
             particular quantization bitwidth
 
@@ -105,8 +105,11 @@ def tse_mlp_cse2018(numerical_columns=None,
 
 
 def tse_mlp_cse2018_pretrained():
-    model_name = 'tse_mlp_cse2018_wq2_aq4_iq0.hdf5'
+    model_name = 'tse_mlp_cse2018_wq2_aq4_iq0.tar.gz'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
-                          cache_subdir='models')
-    return load_quantized_model(model_path)
\ No newline at end of file
+                          cache_subdir='models',
+                          extract=True)
+    file_path = os.path.join(os.path.dirname(model_path),
+                             "tse_mlp_cse2018_wq2_aq4_iq0")
+    return load_quantized_model(file_path)
