@@ -52,8 +52,8 @@ def ds_cnn_kws(input_shape,
             be specified if `include_top` is True.
         include_top (bool): whether to include the fully-connected
             layer at the top of the model.
-        weights (str): one of `None` (random initialization), 'kws' for
-            pretrained weights or the path to the weights file to be loaded.
+        weights (str): one of `None` (random initialization) or the path to the
+            weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -176,4 +176,4 @@ def ds_cnn_kws_pretrained():
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
-    return load_quantized_model(model_path)
\ No newline at end of file
+    return load_quantized_model(model_path)
