@@ -53,8 +53,8 @@ def ds_cnn_edge_kws(input_shape,
             be specified if `include_top` is True.
         include_top (bool): whether to include the fully-connected
             layer at the top of the model.
-        weights (str): one of `None` (random initialization), 'kws' for
-            pretrained weights or the path to the weights file to be loaded.
+        weights (str): one of `None` (random initialization) or the path to the
+            weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -188,8 +188,11 @@ def ds_cnn_edge_kws(input_shape,
     return model
 
 
-def ds_cnn_edge_kws_pretrained():
-    model_name = 'ds_cnn_kws_wq4_aq4_no_top.hdf5'
+def ds_cnn_edge_kws_pretrained(include_top=True):
+    if include_top:
+        model_name = 'ds_cnn_edge_kws_wq4_aq4.hdf5'
+    else:
+        model_name = 'ds_cnn_edge_kws_wq4_aq4_no_top.hdf5'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
